<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!-- xslt for Garzantine -->
	<!-- using us-ascii encoding because special characters like &#49; would be replaced during transformation when using UTF-8 -->
	<xsl:output method="html" encoding="us-ascii" doctype-public="-//W3C//DTDXHTML 1.0 Transitional//EN" doctype-system="https://www.w3.org/TR/html4/strict.dtd" />
	
    <!-- string parameters -->	
    <xsl:param name="view.details.headimage"/>		
	<xsl:param name="view.details.base"/>
	<xsl:param name="view.details.id"/>
	<xsl:param name="view.details.section"/>
	<xsl:param name="tooltip-xml"/>
			
	<xsl:template match="ENTRY">
		<xsl:text>
				<script type="text/javascript">
				window.MathJax = {
					extensions: ["tex2jax.js"],
					jax: ["input/TeX", "output/HTML-CSS"],
					TeX: {
					    extensions: ["AMSmath.js","AMSsymbols.js"]
    					},
					tex2jax: {
						inlineMath: [ ['$','$'] ],
						displayMath: [ ['$$','$$'] ],
						processEscapes: true,
						preview: ["Converting LaTex formula..."]
						},
					showProcessingMessages: false,
					messageStyle: "none",
					showMathMenu: false,
					"HTML-CSS": {
						webFont: null,
						availableFonts: [],
						imageFont: "TeX"
						}						
					};
					</script>
		</xsl:text>
	<xsl:if test="string-length(@LaTex) &gt; 0">
			<script type="text/javascript" src="gzeco/external/MathJax/MathJax.js"></script>
	</xsl:if>
	<table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:100%; border:0">
		<tr>
			<td class="FG">&#160;</td>
			<td class="Fascia" valign="middle" align="center">Garzantina dell’Economia</td>
		</tr>
				<xsl:if test="string-length(@TabNumber) &gt; 0">
					<tr><td class="Tasti" colspan="2"><xsl:apply-templates select="TABS" /><br/><br/><br/><hr class="Linea"></hr></td></tr>
				</xsl:if>
				<tr><td valign="top" height="100%" colspan="2">
					<div class="Entry">
						<xsl:apply-templates select="HEAD" />
						<xsl:apply-templates select="BODY" />
					</div>
		</td></tr>
	</table>
	</xsl:template>

	<xsl:template match="HEAD">
		<xsl:apply-templates />	
	</xsl:template>

	<xsl:template match="Xref">
			<xsl:variable name="link"><xsl:value-of select="@Link"/></xsl:variable>
				<a class="Xref" href="javascript:detail('{$link}')"><xsl:apply-templates /></a>
	</xsl:template>

	<xsl:template match="XrefExt">
		<xsl:variable name="link"><xsl:value-of select="@Link"/></xsl:variable>
		<xsl:variable name="target"><xsl:value-of select="@Target"/></xsl:variable>
		<xsl:text>
			<script language="JavaScript">
			function WinOpen(theURL) { newWin = open(""+theURL+"","DisplayWindow","resizable=yes,scrollbars=yes,toolbar=no,width=800,height=800,left=200,top=50"); newWin.focus() }
			</script>
		</xsl:text>
			<a class="Xref" onClick="WinOpen('gzeco/external/Html/{$link}.html#{$target}'); return false;" href="#" target="_self"><xsl:apply-templates /></a>
	</xsl:template>

	<xsl:template match="Button">
		<xsl:variable name="link"><xsl:value-of select="@Link"/></xsl:variable>
		<xsl:variable name="tooltip"><xsl:value-of select="@Text"/></xsl:variable>
		<xsl:text>
			<script language="JavaScript">
			function WinOpen(theURL) { newWin = open(""+theURL+"","DisplayWindow","resizable=yes,scrollbars=yes,toolbar=no,width=800,height=800,left=200,top=50"); newWin.focus() }
			</script>
		</xsl:text>
			<a class="TabB1" onClick="WinOpen('gzeco/external/Html/{$link}.html'); return false;" href="#" target="_self">GRAFICI&#160;E&#160;TABELLE</a>
	</xsl:template>

	<xsl:template match="BODY">
		<xsl:apply-templates />	
	</xsl:template>

	<xsl:template match="Img">
		<xsl:variable name="filename"><xsl:value-of select="@File"/></xsl:variable>
		<center><img src="gzeco/images/{$filename}" alt="" border=""/></center>
	</xsl:template>

	<!-- paragraph tags  -->
	<xsl:template match="Part">
	<xsl:if test="string(@Type) = 'Rim'">
		<div class="Rimandi">
			<xsl:apply-templates />
		</div>
	</xsl:if>
	<xsl:if test="string-length(@Type) = 0">
		<div class="Part">
			<xsl:apply-templates />
		</div>
	</xsl:if>
	</xsl:template>

	<xsl:template match="XReference">
		<div class="XReference">
			<xsl:apply-templates />
		</div>
	</xsl:template>

	<xsl:template match="Eq">
		<!-- Ignore -->
	</xsl:template>

	<xsl:template match="Htit">
		<P class="Htit">
			<xsl:apply-templates />
		</P>
	</xsl:template>
	<xsl:template match="Para">
		<P class="Para">
			<xsl:apply-templates />
		</P>
	</xsl:template>
	<xsl:template match="ParaLatex">
		<P class="ParaLatex">
			<xsl:apply-templates />
		</P>
	</xsl:template>

	<xsl:template match="Firma">
		<div class="Firma">
			<xsl:apply-templates />
		</div>
	</xsl:template>
	<xsl:template match="ParaImg">
		<P class="ParaImg">
			<xsl:apply-templates />
		</P>
	</xsl:template>

	<!-- Character replacments -->
	<xsl:template match="sp">
		<xsl:variable name="tooltip"><xsl:value-of select='document(concat($tooltip-xml, "Explosion-Sp.xml"))/tooltips/sp[@short=current()]/@long'/></xsl:variable>
		<span class="sp" title="{$tooltip}"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="HwHid">
		<!-- ignore -->
	</xsl:template>
	<xsl:template match="Hword">
		<span class="Hword"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="HwordRim">
		<span class="Hword"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="Hname">
		<span class="Hname"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="SubHword">
		<span class="SubHword"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="ParaTab">
			<table class="Tabella"><xsl:apply-templates /></table>
	</xsl:template>
	<xsl:template match="Tab">
			<tr><xsl:apply-templates /></tr>
	</xsl:template>
	<xsl:template match="t">
			<td class="tab"><xsl:apply-templates /></td>
	</xsl:template>
	<xsl:template match="t1">
			<td class="tab1"><xsl:apply-templates /></td>
	</xsl:template>
	<xsl:template match="Alias">
		<span class="Alias"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="TitPara">
		<span class="TitPara"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="TitPara1">
		<span class="TitPara1"><xsl:apply-templates /></span>
	</xsl:template>

	<xsl:template match="Note">
		<P class="Note"><xsl:apply-templates /></P>
	</xsl:template>
	<xsl:template match="Omo">
		<sup><xsl:apply-templates /></sup>
	</xsl:template>

	<xsl:template match="HL">
		<xsl:variable name="hlidx1"><xsl:value-of select="attribute::index"/></xsl:variable>
		<xsl:variable name="nodeName" select="name()"></xsl:variable>
		<xsl:variable name="hlidx2"><xsl:value-of select="count(preceding::node()[name() = $nodeName]) + 1"/></xsl:variable>
		<a id="hl_{$hlidx1}_{$hlidx2}_{$view.details.id}" class="ancor"></a>
		<span class="HL"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="TT">
		<span class="tt"><xsl:apply-templates /></span>
	</xsl:template>
	<xsl:template match="sup">
		<sup><xsl:apply-templates /></sup>
	</xsl:template>	
	<xsl:template match="sub">
		<sub><xsl:apply-templates /></sub>
	</xsl:template>	
	<xsl:template match="b">
		<b><xsl:apply-templates /></b>
	</xsl:template>	
	<xsl:template match="i">
		<i><xsl:apply-templates /></i>
	</xsl:template>	
	<xsl:template match="m">
		<span class="m"><xsl:apply-templates /></span>
	</xsl:template>	

</xsl:stylesheet>
